@@ -1,15 +1,10 @@
-use orbiter_rs::{
-   debug_string, OrbiterVessel, init_vessel, SDKVessel, FileHandle
-};
-pub struct MinimalPB
-{
-    ctx: SDKVessel
+use orbiter_rs::{debug_string, init_vessel, FileHandle, OrbiterVessel, SDKVessel};
+pub struct MinimalPB {
+    ctx: SDKVessel,
 }
 impl MinimalPB {
     pub fn new(vessel: SDKVessel) -> Self {
-        Self {
-            ctx: vessel
-        }
+        Self { ctx: vessel }
     }
 }
 impl OrbiterVessel for MinimalPB {
@@ -17,8 +12,7 @@ impl OrbiterVessel for MinimalPB {
         self.ctx.SetSize(1.0);
         self.ctx.AddMesh("ShuttlePB".into());
     }
-    fn on_pre_step(&mut self, sim_t: f64, _sim_dt: f64, _mjd: f64)
-    {
+    fn on_pre_step(&mut self, sim_t: f64, _sim_dt: f64, _mjd: f64) {
         debug_string!("Hello world! sim_t: {:.2}", sim_t);
     }
 }
