@@ -1,6 +1,5 @@
 // This file is included directly from lib.rs as making it into a module created too many hassles
 use std::os::raw::c_char;
-
 mod vector;
 
 pub use vector::Vector3;
@@ -14,10 +13,17 @@ unsafe impl cxx::ExternType for VECTOR3 {
 ctype_wrapper!(THRUSTER_HANDLE, usize, ThrusterHandle); 
 ctype_wrapper!(PROPELLANT_HANDLE, usize, PropellantHandle);
 ctype_wrapper!(THGROUP_HANDLE, usize, ThrustGroupHandle);
-ctype_wrapper!(FILEHANDLE, usize, FileHandle);
 ctype_wrapper!(OBJHANDLE, usize);
 ctype_wrapper!(DWORD, u32);
 
+mod io;
+pub use io::FileHandle;
+pub type FILEHANDLE = io::FileHandle;
+unsafe impl cxx::ExternType for FILEHANDLE {
+    type Id = cxx::type_id!("FILEHANDLE");
+    type Kind = cxx::kind::Trivial;
+}
+
 /// Binding for OrbiterSDK's `VESSELSTATUS` struct
 #[repr(C)]
 #[derive(Debug, Default)]
@@ -175,6 +181,44 @@ pub mod ffi {
         #[cxx_name = "ALTMODE_GROUND"]
         Ground
     }
+
+    #[derive(Debug)]
+    #[repr(usize)]
+    enum FileAccessMode {
+        /// Read
+        #[cxx_name = "FILE_IN"]
+        In,
+        /// Write
+        #[cxx_name = "FILE_OUT"]
+        Out,
+        /// Write (append)
+        #[cxx_name = "FILE_APP"]
+        Append,
+        /// Read (zero on fail)
+        #[cxx_name = "FILE_IN_ZEROONFAIL"]
+        In_ZeroOnFail,
+    }
+
+    #[derive(Debug)]
+    #[repr(usize)]
+    enum PathRoot {
+        #[cxx_name = "ROOT"]
+        Root,
+        #[cxx_name = "CONFIG"]
+        Config,
+        #[cxx_name = "SCENARIOS"]
+        Scenarios,
+        #[cxx_name = "TEXTURES"]
+        Textures,
+        #[cxx_name = "TEXTURES2"]
+        Textures2,
+        #[cxx_name = "MESHES"]
+        Meshes,
+        #[cxx_name = "MODULES"]
+        Modules,
+    }
+
+
     unsafe extern "C++" {
         include!("include/vessel_context.h");
         #[doc(hidden)]
@@ -279,9 +323,36 @@ pub mod ffi {
 
         /// Print message to lower-left corner of screen. For debugging purposes only!
         fn ODebug(s: String);
+
+        type FileAccessMode;
+        type PathRoot;
+
+        unsafe fn oapiReadItem_string(f: FILEHANDLE, item: *mut c_char, val: *mut c_char) -> bool;
+        unsafe fn oapiReadItem_float(f: FILEHANDLE, item: *mut c_char, val: &mut f64) -> bool;
+        unsafe fn oapiReadItem_int(f: FILEHANDLE, item: *mut c_char, val: &mut i32) -> bool;
+        unsafe fn oapiReadItem_bool(f: FILEHANDLE, item: *mut c_char, val: &mut bool) -> bool;
+        unsafe fn oapiReadItem_vec(f: FILEHANDLE, item: *mut c_char, val: &mut VECTOR3) -> bool;
+
+        unsafe fn oapiWriteItem_string(f: FILEHANDLE, item: *mut c_char, val: *mut c_char);
+        unsafe fn oapiWriteItem_float(f: FILEHANDLE, item: *mut c_char, val: f64);
+        unsafe fn oapiWriteItem_int(f: FILEHANDLE, item: *mut c_char, val: i32);
+        unsafe fn oapiWriteItem_bool(f: FILEHANDLE, item: *mut c_char, val: bool);
+        unsafe fn oapiWriteItem_vec(f: FILEHANDLE, item: *mut c_char, val: &VECTOR3);
+
+        unsafe fn oapiWriteLine(f: FILEHANDLE, line: *mut c_char);
+
+        unsafe fn oapiOpenFile(
+            fname: *const c_char,
+            mode: FileAccessMode,
+            root: PathRoot,
+        ) -> FILEHANDLE;
+        fn oapiCloseFile(f: FILEHANDLE, mode: FileAccessMode);
+
+        /// Writes a line to the Orbiter log file (orbiter.log) in the main orbiter directory
+        unsafe fn oapiWriteLog(line: *mut c_char);
     }
     extern "Rust" {
-        fn dyn_vessel_set_class_caps(vessel: &mut BoxDynVessel, cfg: FILEHANDLE);
+        fn dyn_vessel_set_class_caps(vessel: &mut BoxDynVessel, cfg: &FILEHANDLE);
         fn dyn_vessel_pre_step(
             vessel: &mut BoxDynVessel,
             sim_t: f64,
@@ -324,7 +395,7 @@ unsafe fn dyn_vessel_drop_in_place(ptr: PtrBoxDynVessel) {
 }
 
 // trait fn shims
-fn dyn_vessel_set_class_caps(vessel: &mut Box<dyn OrbiterVessel>, cfg: FileHandle) {
+fn dyn_vessel_set_class_caps(vessel: &mut Box<dyn OrbiterVessel>, cfg: &FileHandle) {
     (**vessel).set_class_caps(cfg);
 }
 fn dyn_vessel_pre_step(
@@ -355,18 +426,19 @@ unsafe fn dyn_vessel_consume_buffered_key(
 
 pub use ffi::VesselContext;
 impl std::fmt::Debug for VesselContext {
-    fn fmt(&self, fmt:&mut std::fmt::Formatter) -> std::fmt::Result {
+    fn fmt(&self, fmt: &mut std::fmt::Formatter) -> std::fmt::Result {
         fmt.debug_struct("VesselContext").finish()
     }
 }
 #[doc(hidden)]
 pub use ffi::BoxDynVessel;
 
-pub use ffi::ODebug;
 pub use ffi::oapi_create_vessel;
+pub use ffi::ODebug;
+
+pub use ffi::REFFRAME as ReferenceFrame;
 /// Type alias for [THGROUP_TYPE]
 pub use ffi::THGROUP_TYPE as ThrusterGroupType;
-pub use ffi::REFFRAME as ReferenceFrame;
 
 /// A wrapper over the FFI interface to the Orbiter SDK
 /// This is passed to the init() function in the `[init_vessel!]` macro
